#!/usr/bin/python3
# -*- coding: utf-8 -*-

#    npzviewer
#    Copyright (C) 2018  Érico Vieira Porto
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

from PyQt5 import QtWidgets, QtCore
from pathlib import Path
import os.path
import numpy as np

class MainWindow(QtWidgets.QMainWindow):
    def __init__(self, filelist, **kwargs):
        QtWidgets.QWidget.__init__(self)
        self.button = QtWidgets.QPushButton('Load .npz file', self)
        self.plaintext = QtWidgets.QPlainTextEdit(self)
        self.plaintext.setReadOnly(True)
        
        self.button.clicked.connect(self.handleButton)

        self.centralwidget = QtWidgets.QWidget()
        self.setCentralWidget(self.centralwidget)
        layout = QtWidgets.QVBoxLayout(self.centralwidget)
        layout.addWidget(self.button)
        layout.addWidget(self.plaintext)
        self.setAcceptDrops(True)
        self.opemFileIfDropped(filelist)

    def openFileByName(self, np_filename):
        my_np_file = Path(np_filename)
        if not my_np_file.is_file():
          return

        npz_loaded_file = np.load(my_np_file)

        k_files = npz_loaded_file.__dict__['files']

        k_files.sort()

        self.plaintext.clear()

        for k in k_files:
          self.plaintext.appendPlainText(k +' :')
          self.plaintext.appendPlainText(str(npz_loaded_file[k]))
          self.plaintext.appendPlainText('---')

        #print (np_filename)


    def opemFileIfDropped(self, filelist):
        if (isinstance(filelist, str)):
            if (".npz" in filelist):
                self.openFileByName(filelist)

        else:
            matching = [s for s in filelist if ".npz" in s]
            if len(matching) > 0:
                self.openFileByName(matching[0])

    def dragEnterEvent(self, event):
        if event.mimeData().hasUrls:
            extension = os.path.splitext(event.mimeData().urls()[0].toLocalFile())[1]
            if extension == '.npz':
                event.accept()
                return
        
        event.ignore()

    def dragMoveEvent(self, event):
        if event.mimeData().hasUrls:
            extension = os.path.splitext(event.mimeData().urls()[0].toLocalFile())[1]
            if extension == '.npz':
                event.accept()
                return
        
        event.ignore()

    def dropEvent(self, event):
        if event.mimeData().hasUrls:
            event.accept()
            self.opemFileIfDropped(event.mimeData().urls()[0].toLocalFile())

        else:
            event.ignore()

    def handleButton(self):
        np_filename = QtWidgets.QFileDialog.getOpenFileName(
            self, 'Open File', "~", "NPZ file (*.npz);;All Files (*)")[0]

        self.openFileByName(np_filename)




#!/usr/bin/python3
# -*- coding: utf-8 -*-
import os
import sys
from PyQt5.QtWidgets import QApplication
import argparse
if os.path.isdir(os.path.join(".","src")) and os.path.isfile(
        os.path.join(".","setup.py")):
    sys.path.append(os.path.realpath("src"))
    sys.path.append(os.path.realpath("src/npzviewer"))

from npzviewer import __title__, __version__, __copyright__, __license__
from npzviewer.npzviewer import MainWindow

def main():
    """"
    npzviewer main routine

    When you use `python -m npzviewer`, the main routine is called.
    If you use `pip install npzviewer`, typing npzviewer will also call this routine.

    The objective of this function is to:
    1. load the npzviewer when called without args
    2. if the arg is a .npz file, and no additional args, load the npzviewer and open the file.npz
    3. seeing the current version by using `--version`, and not opening the npzviewer

    """

    __title__ + " comes with ABSOLUTELY NO WARRANTY \nThis is free software, and you are welcome to redistribute it"

    parser = argparse.ArgumentParser(
                prog=__title__,
                description=__title__ + ' is a .npz viewer, for numpy saved files.' + "\n" +
                   __title__ + " comes with ABSOLUTELY NO WARRANTY. \nThis is free software, and you are welcome to redistribute it." ,
                epilog=__copyright__ + ", " + __license__ +".")
    parser.add_argument('-v', '--version', action='store_true', default=False, help='get software version.')
    parser.add_argument('npzfile', nargs='?', default='no_npzfile', help='a single .npz file')
    args = parser.parse_args()

    if args.version == True:
        print(__title__ + "  v " + __version__ )
        exit()

    a = QApplication([])

    mw_arg=[]
    if 'npzfile' in args:
        mw_arg = [args.npzfile]

    mw = MainWindow(mw_arg)
    a.processEvents()
    mw.show()
    mw.raise_()
    exit(a.exec_())

if __name__ == '__main__':
    main()





# -*- coding: utf-8 -*-
from setuptools import setup
from codecs import open
import platform
import errno
import sys
import os
import re

here = os.path.abspath(os.path.dirname(__file__))

# Get the long description from the README file
with open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

datafiles = dict(data_files=[])
osname = platform.system()

with open('npzviewer/__init__.py', 'r') as fd:
    version = re.search(r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]',
                        fd.read(), re.MULTILINE).group(1)

if(int(sys.version_info.major) == 2):
    install_requires = ['numpy']
    print("!!!Please INSTALL PYQT5!!!")
else:
    install_requires = ['numpy','pyqt5']

setup(
    name='npzviewer',
    version=version,
    description='A simple PyQt5 .npz file viewer.',
    long_description=long_description,
    url='https://github.com/ericoporto/npzviewer',
    download_url = 'https://github.com/ericoporto/npzviewer/tarball/'+version,
    author='Erico Vieira Porto',
    author_email='eri0onpm@gmail.com',
    license='GPLv2',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v2 (GPLv2)',
        'Programming Language :: Python :: 3.5'
    ],
    keywords='numpy development',
    install_requires=install_requires,
    packages = ["npzviewer"],
    entry_points={
        'gui_scripts': [
            'npzviewer = npzviewer.__main__:main'
            ]
    }
)
